<?php
add_action('widgets_init', create_function('', 'return register_widget("music_post_widget");'));

class music_post_widget extends WP_Widget{
  /** Constructor */
  function __construct() {
    parent::__construct( 'music_post_widget', __( 'Musics - W*P*L*O*C*K*E*R*.*C*O*M', 'musik' ), array( 'description' => __( 'Display the musics or albums', 'musik' ) ) );
  }

  /** @see WP_Widget::widget */
  function widget( $args, $instance ) {
    // Set defaults
    $args['id'] = ( isset( $args['id'] ) ) ? $args['id'] : 'edd_post_widget';
    $title      = apply_filters('widget_title', isset( $instance['title'] ) ? $instance['title'] : '' );
    $subtitle   = isset( $instance['subtitle'] ) ? $instance['subtitle'] : '';
    $type       = isset( $instance['type'] ) ? $instance['type'] : '';
    $orderby    = isset( $instance['orderby'] ) ? $instance['orderby'] : 'rand';
    $order      = isset( $instance['order'] ) ? $instance['order'] : 'DESC';
    $count      = isset( $instance['count'] ) ? $instance['count'] : 6;
    $display    = isset( $instance['display'] ) ? $instance['display'] : 'grid';
    $column     = isset( $instance['column'] ) ? $instance['column'] : 6;
    $pagination = isset( $instance['pagination'] ) ? $instance['pagination'] : '';
    $category   = isset( $instance['category'] ) ? $instance['category'] : '';
    $exclude    = isset( $instance['exclude'] ) ? $instance['exclude'] : false;
    $widget     = isset( $instance['widget'] ) ? $instance['widget'] : false;

    if(!$widget){
      echo $args['before_widget'];
    }

    $paged = 1;
    if($pagination == 'on'){
      if ( get_query_var('paged') ) {
          $paged = get_query_var('paged');
      } elseif ( get_query_var('page') ) {
          $paged = get_query_var('page');
      }
    }

    $wrap = '<div class="list-group list-group-lg">';
    $wrap_el = '<div class="list-group-item">';
    $tpl = 'download-list';

    if($display == 'grid'){
        $wrap = '<div class="row row-sm">';
        $class = 'col-xs-6';
        switch($column){
          case 2:
            $class = $class;
            break;
          case 3:
            $class .= ' col-sm-4';
            break;
          case 4:
            $class .= ' col-sm-4 col-md-3';
            break;
          case 6:
            $class .= ' col-sm-4 col-md-3 col-lg-2';
            break;
        }
        $wrap_el = '<div class="'. esc_attr( $class ) .'">';
        $tpl = 'download';
    }

    $arg = array(
      'post_type'       => 'download',
      'orderby'         =>  $orderby,
      'order'           =>  $order,
      'posts_per_page'  =>  $count,
      'paged'           =>  $paged
    );

    if($type == 'bundle'){
      $arg['meta_query'] = array(
        array(
          'key'   => '_edd_product_type',
          'value' => 'bundle'
        )
      );
    }

    if($type == 'single'){
      $arg['meta_query'] = array(
        array(
          'key'   => 'music_type',
          'value' => 'single'
        )
      );
    }

    if($orderby == 'sales'){
      $arg['orderby']   = 'meta_value';
      $arg['meta_key']   = '_edd_download_sales';
    }

    // get the related
    if( is_single() && $exclude ){
      $arg['post__not_in'] = array( get_queried_object()->ID );
      $terms = wp_get_object_terms( get_queried_object()->ID, 'download_category', array('fields' => 'ids'));
      if (!is_wp_error( $terms ) && '' != $terms ) {
        $arg['tax_query'] = array(
          array(
            'taxonomy' => 'download_category',
            'field'    => 'term_id',
            'terms'    => $terms
          )
        );
      }
    }

    query_posts( $arg );

    if(have_posts()){

      if($title != ''){
        echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
      }
      if($subtitle != ''){
        echo '<h5 class="sub-title">'. esc_html( $subtitle ) .'</h5>';
      }
      echo $wrap;
      while(have_posts()){
        the_post();
        ?>
          <?php echo $wrap_el; ?>
              <?php get_template_part( 'template-parts/content', $tpl ); ?>
          <?php
          echo '</div>';
      }
      echo '</div>';
      if($pagination == 'on'){
        get_template_part( 'template-parts/pagination'); 
      }

    }

    wp_reset_query();

    if(!$widget){
      echo $args['after_widget'];
    }
  }

  /** @see WP_Widget::update */
  function update($new_instance, $old_instance){
    $instance = $old_instance;
    $instance['title']    = strip_tags($new_instance['title']);
    $instance['subtitle'] = strip_tags($new_instance['subtitle']);
    $instance['type']     = strip_tags($new_instance['type']);
    $instance['orderby']  = strip_tags($new_instance['orderby']);
    $instance['order']    = strip_tags($new_instance['order']);
    $instance['count']    = strip_tags($new_instance['count']);
    $instance['display']  = strip_tags($new_instance['display']);
    $instance['column']   = strip_tags($new_instance['column']);
    $instance['pagination']    = strip_tags($new_instance['pagination']);
    return $instance;
  }

  /** @see WP_Widget::form */
  function form( $instance ) {
    // Set up some default widget settings.
    $defaults = array(
      'title'    => '',
      'subtitle' => '',
      'type'     => 'all',
      'orderby'  => 'rand',
      'order'    => 'DESC',
      'count'    => 6,
      'display'  => 'Grid',
      'column'   => 4,
      'pagination'   => ''
    );

    $instance = wp_parse_args((array) $instance, $defaults);
    ?>

    <p>
      <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'musik'); ?></label>
      <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('subtitle'); ?>"><?php _e('Sub Title:', 'musik'); ?></label>
      <input type="text" class="widefat" id="<?php echo $this->get_field_id( 'subtitle' ); ?>" name="<?php echo $this->get_field_name( 'subtitle' ); ?>" value="<?php echo $instance['subtitle']; ?>" />
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('type'); ?>"><?php _e('Type:', 'musik'); ?></label>
      <select name="<?php echo esc_attr( $this->get_field_name( 'type' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'type' ) ); ?>">
        <option value="all" <?php selected( 'all', $instance['type'] ); ?>><?php _e('All', 'musik'); ?></option>
        <option value="single" <?php selected( 'single', $instance['type'] ); ?>><?php _e('Single', 'musik'); ?></option>
        <option value="bundle" <?php selected( 'bundle', $instance['type'] ); ?>><?php _e('Bundle', 'musik'); ?></option>
      </select>
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('orderby'); ?>"><?php _e('Order by:', 'musik'); ?></label>
      <select name="<?php echo esc_attr( $this->get_field_name( 'orderby' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>">
        <option value="rand" <?php selected( 'rand', $instance['orderby'] ); ?>><?php _e('Random', 'musik'); ?></option>
        <option value="name" <?php selected( 'name', $instance['orderby'] ); ?>><?php _e('Name', 'musik'); ?></option>
        <option value="date" <?php selected( 'date', $instance['orderby'] ); ?>><?php _e('Date', 'musik'); ?></option>
        <option value="meta_value_num" <?php selected( 'meta_value_num', $instance['orderby'] ); ?>><?php _e('View', 'musik'); ?></option>
        <option value="sales" <?php selected( 'sales', $instance['orderby'] ); ?>><?php _e('Sales', 'musik'); ?></option>
      </select>
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('order'); ?>"><?php _e('Order:', 'musik'); ?></label>
      <select name="<?php echo esc_attr( $this->get_field_name( 'order' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>">
        <option value="ASC" <?php selected( 'ASC', $instance['order'] ); ?>><?php _e('ASC', 'musik'); ?></option>
        <option value="DESC" <?php selected( 'DESC', $instance['order'] ); ?>><?php _e('DESC', 'musik'); ?></option>
      </select>
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('display'); ?>"><?php _e('Display:', 'musik'); ?></label>
      <select name="<?php echo esc_attr( $this->get_field_name( 'display' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'display' ) ); ?>">
        <option value="list" <?php selected( 'list', $instance['display'] ); ?>><?php _e('List', 'musik'); ?></option>
        <option value="grid" <?php selected( 'grid', $instance['display'] ); ?>><?php _e('Grid', 'musik'); ?></option>
      </select>
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('column'); ?>"><?php _e('Grid Column:', 'musik'); ?></label>
      <select name="<?php echo esc_attr( $this->get_field_name( 'column' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'column' ) ); ?>">
        <option value="2" <?php selected( '2', $instance['column'] ); ?>>2</option>
        <option value="3" <?php selected( '3', $instance['column'] ); ?>>3</option>
        <option value="4" <?php selected( '4', $instance['column'] ); ?>>4</option>
        <option value="6" <?php selected( '6', $instance['column'] ); ?>>6</option>
      </select>
    </p>

    <p>
      <label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Count:', 'musik'); ?></label>
      <input type="text" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" value="<?php echo $instance['count']; ?>" />
    </p>

    <p>
      <label for="<?php echo $this->get_field_id( 'pagination' ); ?>"><?php _e( 'Show Pagination:', 'musik' ); ?></label>
      <input <?php checked( $instance['pagination'], 'on' ); ?> id="<?php echo $this->get_field_id( 'pagination' ); ?>" name="<?php echo $this->get_field_name( 'pagination' ); ?>" type="checkbox" />
    </p>

    <?php
  }
}
?>
